@@ -1,14 +1,17 @@
 """ imports for AindModel subclasses
 """
 
-__version__ = "0.13.30"
+__version__ = "0.13.42"
 
 
+from .behavior.behavior_rig import BehaviorRig
+from .behavior.behavior_session import BehaviorSession
 from .data_description import DataDescription, DerivedDataDescription, Funding, RawDataDescription
 from .ephys.ephys_rig import EphysRig
 from .ephys.ephys_session import EphysSession
 from .imaging.acquisition import Acquisition, Axis
 from .imaging.instrument import Instrument
+from .imaging.mri_session import MriSession
 from .ophys.ophys_rig import OphysRig
 from .ophys.ophys_session import OphysSession
 from .procedures import Procedures
@@ -32,4 +35,9 @@ __all__ = [
     "OphysRig",
     "OphysSession",
     "Axis",
+    "BehaviorRig",
+    "BehaviorSession",
+    "OphysSession",
+    "OphysRig",
+    "MriSession",
 ]
