@@ -6,14 +6,14 @@ from typing import List, Optional, Union
 
 from pydantic import Field
 
-from ..base import AindCoreModel
-from ..device import CameraAssembly, DAQDevice, Device, Disc, HarpDevice, Monitor, Treadmill, Tube
+from aind_data_schema.base import AindCoreModel
+from aind_data_schema.device import CameraAssembly, DAQDevice, Device, Disc, HarpDevice, Monitor, Treadmill, Tube
 
 
 class BehaviorRig(AindCoreModel):
     """Description of an behavior rig"""
 
-    schema_version: str = Field("0.0.1", description="schema version", title="Version", const=True)
+    schema_version: str = Field("0.0.2", description="schema version", title="Version", const=True)
     rig_id: str = Field(..., description="room_stim apparatus_version", title="Rig ID")
     cameras: Optional[List[CameraAssembly]] = Field(None, title="Camera assemblies", unique_items=True)
     visual_monitors: Optional[List[Monitor]] = Field(None, title="Visual monitors", unique_items=True)
