@@ -9,7 +9,7 @@ from typing import List, Optional
 
 from pydantic import Field
 
-from .base import AindCoreModel, AindModel, BaseName, BaseNameEnumMeta, PIDName
+from aind_data_schema.base import AindCoreModel, AindModel, BaseName, BaseNameEnumMeta, PIDName
 
 
 class RegexParts(Enum):
@@ -44,16 +44,31 @@ class DataLevel(Enum):
 class Institution(Enum, metaclass=BaseNameEnumMeta):
     """Institution name"""
 
-    AIBS = PIDName(name=BaseName(name="Allen Institute for Brain Science", abbreviation="AIBS"),
-                    registry=BaseName(name="Research Organization Registry",abbreviation="ROR"), registry_identifier="00dcv1019")
-    AIND = PIDName(name=BaseName(name="Allen Institute for Neural Dynamics", abbreviation="AIND"),
-                    registry=BaseName(name="Research Organization Registry",abbreviation="ROR"), registry_identifier="04szwah67")
-    COLUMBIA = PIDName(name=BaseName(name="Columbia University", abbreviation="Columbia"),
-                    registry=BaseName(name="Research Organization Registry",abbreviation="ROR"), registry_identifier="00hj8s172")
-    HUST = PIDName(name=BaseName(name="Huazhong University of Science and Technology", abbreviation="HUST"),
-                    registry=BaseName(name="Research Organization Registry",abbreviation="ROR"), registry_identifier="00p991c53")
-    NYU = PIDName(name=BaseName(name="New York University", abbreviation="NYU"),
-                    registry=BaseName(name="Research Organization Registry",abbreviation="ROR"), registry_identifier="0190ak572")
+    AIBS = PIDName(
+        name=BaseName(name="Allen Institute for Brain Science", abbreviation="AIBS"),
+        registry=BaseName(name="Research Organization Registry", abbreviation="ROR"),
+        registry_identifier="00dcv1019",
+    )
+    AIND = PIDName(
+        name=BaseName(name="Allen Institute for Neural Dynamics", abbreviation="AIND"),
+        registry=BaseName(name="Research Organization Registry", abbreviation="ROR"),
+        registry_identifier="04szwah67",
+    )
+    COLUMBIA = PIDName(
+        name=BaseName(name="Columbia University", abbreviation="Columbia"),
+        registry=BaseName(name="Research Organization Registry", abbreviation="ROR"),
+        registry_identifier="00hj8s172",
+    )
+    HUST = PIDName(
+        name=BaseName(name="Huazhong University of Science and Technology", abbreviation="HUST"),
+        registry=BaseName(name="Research Organization Registry", abbreviation="ROR"),
+        registry_identifier="00p991c53",
+    )
+    NYU = PIDName(
+        name=BaseName(name="New York University", abbreviation="NYU"),
+        registry=BaseName(name="Research Organization Registry", abbreviation="ROR"),
+        registry_identifier="0190ak572",
+    )
 
     @classmethod
     def __modify_schema__(cls, field_schema):
