@@ -5,6 +5,7 @@ import unittest
 
 import pydantic
 
+from aind_data_schema.behavior import behavior_rig as br
 from aind_data_schema.behavior import behavior_session as bs
 
 
@@ -36,6 +37,10 @@ class BehaviorTests(unittest.TestCase):
 
         assert b is not None
 
+        r = br.BehaviorRig(rig_id="1234")
+
+        assert r is not None
+
 
 if __name__ == "__main__":
     unittest.main()
