@@ -121,7 +121,7 @@ class ExampleTest(unittest.TestCase):
         assert rig is not None
 
         sess = es.EphysSession(
-            experimenter_full_name="alice",
+            experimenter_full_name=["alice"],
             session_start_time=datetime.datetime.now(),
             session_end_time=datetime.datetime.now(),
             subject_id="1234",
@@ -131,14 +131,15 @@ class ExampleTest(unittest.TestCase):
                 es.Stream(
                     stream_start_time=datetime.datetime.now(),
                     stream_end_time=datetime.datetime.now(),
-                    ephys_modules=[es.EphysModule(
-                        ephys_probes=[es.EphysProbe(name="Probe A")],
-                        assembly_name="Ephys_assemblyA",
-                        arc_angle=0,
-                        module_angle=10,
-                        primary_targeted_structure="VISlm",
-                        targeted_ccf_coordinates=[es.CcfCoords(ml="1", ap="1", dv="1")],
-                        manipulator_coordinates=er.Coordinates3d(x="1", y="1", z="1"),
+                    ephys_modules=[
+                        es.EphysModule(
+                            ephys_probes=[es.EphysProbe(name="Probe A")],
+                            assembly_name="Ephys_assemblyA",
+                            arc_angle=0,
+                            module_angle=10,
+                            primary_targeted_structure="VISlm",
+                            targeted_ccf_coordinates=[es.CcfCoords(ml="1", ap="1", dv="1")],
+                            manipulator_coordinates=es.Coordinates3d(x="1", y="1", z="1"),
                         ),
                     ],
                     laser_modules=[],
@@ -146,7 +147,13 @@ class ExampleTest(unittest.TestCase):
                     cameras=[],
                 )
             ],
-            stick_microscopes=[es.DomeModule(assembly_name="Stick_assembly", arc_angle=24, module_angle=10,),],
+            stick_microscopes=[
+                es.DomeModule(
+                    assembly_name="Stick_assembly",
+                    arc_angle=24,
+                    module_angle=10,
+                ),
+            ],
         )
 
         assert sess is not None
